@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import os
 import re
 import sys
@@ -37,9 +38,9 @@ import calculate.lib.utils.device as device
 from calculate.lib.utils.device import (detectDeviceForPartition,
                                         countPartitions)
 from calculate.lib.utils.partition import DiskFactory
-from datavars import DataVarsInstall
+from .datavars import DataVarsInstall
 
-from distr import DistributiveError, PartitionDistributive
+from .distr import DistributiveError, PartitionDistributive
 from subprocess import Popen, PIPE, STDOUT
 from itertools import *
 from calculate.lib.utils.tools import traverse
@@ -49,7 +50,7 @@ class InstallError(Exception):
     """Installation Error"""
 
 
-from migrate_users import migrate
+from .migrate_users import migrate
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 
@@ -508,7 +509,7 @@ class Install(MethodsInterface):
         # если package.mask является файлом - делаем его директорией
         if path.isfile(mask_file):
             os.rename(mask_file, mask_file + "2")
-            os.mkdir(mask_file, mode=0755)
+            os.mkdir(mask_file, mode=0o755)
             os.rename(mask_file + "2", path.join(mask_file, "default"))
         current_nvidia_mask = readFile(nvidia_mask_file).strip()
         new_nvidia_mask = self.clVars.Get('os_nvidia_mask')
